/** Interface of a fetch function. Compatible with the [fetch API](https://developer.mozilla.org/en-US/docs/Web/API/Fetch_API/Using_Fetch) */
export type FetchFunction = (url: string, config: Record<string, any>) => Promise<{
    json: () => Promise<any>;
    ok: boolean;
    status: number;
}>;
/** Basic options for every request */
export type ReplicateRequestOptions = {
    /** Use a custom fetch function. Defaults to the native fetch or `node-fetch` */
    fetch?: FetchFunction;
    /** You need an https://replicate.com API token for nearly all operations. You can generate the token in your [account settings](https://replicate.com/account). */
    token: string;
    /** The actual API endpoint. Defaults to "https://api.replicate.com/v1/" */
    apiUrl?: string;
};
export declare function makeApiRequest<ExpectedResponse = unknown>({ fetch: passedFetchFunction, token, apiUrl }: ReplicateRequestOptions, method: "POST" | "GET", endpoint: string, content?: object): Promise<ExpectedResponse>;
