import { getModel } from "./getModel.js";
import { convertPrediction } from "./helpers/convertPrediction.js";
import { makeApiRequest } from "./helpers/makeApiRequest.js";
/** Create a new prediction
 *
 * ```typescript
 * const result = await predict({
 *   model: "stability-ai/stable-diffusion",
 *   input: { prompt: "multicolor hyperspace" },
 *   token: "Get your token at https://replicate.com/account",
 *   poll: true,
 * })
 * ```
 *
 * Then you can check `result.status` to see if it's `"starting"`, `"processing"` or `succeeded`. If it's `"succeeded"` you can get the outputs with `result.outputs`. If not you can check back later with `getPrediction` and the id from result (`result.id`).
 *
 * If you set the `poll` option this function will return a promise that waits until the prediction is completed.
 */
export const predict = async (options) => {
    const version = "version" in options ? options.version : (await getModel(options)).version;
    const response = await makeApiRequest(options, "POST", "predictions", {
        version: version,
        input: options.input,
        webhook: options.webhook,
        webhook_events_filter: options.webhook ? options.webhookEvents || ["completed"] : undefined,
    });
    const prediction = convertPrediction(options, response);
    return options.poll ? await prediction.poll() : prediction;
};
